
#############################################
### General introduction to R, first part ### 
#############################################

###############################################
### Setting the working directory

#You can use the command "setwd(PATH)" and set the path that leads to the working directory.
#Depending on the operating system, the way to specify the path can be different.

#For Windows:
#setwd("C:/Users/Folder/Sub Folder/...")
#or
#setwd("C:\\Users\\Folder\\Sub Folder\\...")

#For Mac or Linux:
#setwd("~/Folder/Sub Folder/...")

#Type 
setwd(".../Introduction_to_R")

#and now you are running R under the Introduction_to_R directory. 
###############################################
###############################################

###############################################
### R packages

#R is made up of many user-written additional packages, 
#to apply a large variety of methods and techniques

#timeSeries is a package that will be used during the course.
#It needs to be installed in the machine you are using.
#Provided that you are connected to the internet, you can install or update a package 
#using the command "install.packages":
install.packages("timeSeries")

#To access timeSeries (or any other packages) in your current R session, type    
library(timeSeries)

#The functions included in a package can be displayed on your screen with:
help(package=timeSeries)

#Help files of a function can be accessed using either
help(rollMean)

#or
?rollMean

#We may do not know the name of the function. We can search by "words"
help.search("fitting linear models")
###############################################
###############################################

###############################################
### Reading and manipulating data

#R can import dataset of (virtually) any file formats. Probably, the most common ones are .txt, .csv, .DAT.
#Excel files can be imported through the conversion to .csv format.
#To import the file "convergenceIT" according to different file formats:
convergenceIT <- read.csv("convergenceIT.csv", header=T) 
convergenceIT2 <- read.table("convergenceIT.txt", header=T) 
convergenceIT3 <- read.table("convergenceIT.DAT", header=T) 

#The imported datasets take the form of "data frame" objects.
#Data frames are the main workhorse objects in R. 
#A data frames general structure is a rectangular object (a table) 
#comprised of columns of varying data types (say the variables) 
#and rows that each has a value (or missing value, NA) in each column (say observations).

#To visualize the content of a data frame:
dim(convergenceIT)
names(convergenceIT)
str(convergenceIT)
head(convergenceIT)
tail(convergenceIT)
summary(convergenceIT)

#"Geo"      Macroregion
#"gprb"	Log growth rate (1980-2003) of production per capita
#"lninv1b"	PHYSICAL CAPITAL INVESTMENTS (log scale)
#"pr80b"	production per capita 1980
#"pr103b"	production per capita 2003
#"lndens_emp"	EMPLOYMENT DENSITY (log scale)
#"lndens_pop"	Population DENSITY (log scale)
#"lnagrib"	AGRICULTURE EMPLOYMENT SHARE (log scale)

#Selecting subsets of a data frame
#Selecting variables of a data frame according to their names
convergenceIT$Name
convergenceIT$gprb
convergenceIT$Geo

#Selecting the element located at the row 1 and column 3 of the data frameconvergenceIT
convergenceIT[1,3] 

#Selecting the first row of the dataset convergenceIT
convergenceIT[1,] 

#Selecting the third column of the dataset convergenceIT
convergenceIT[,3] 

#Selecting the second and third columns of the dataset convergenceIT
convergenceIT[,c(2,3)] 

#Selecting the first 10 rows of the dataset convergenceIT
convergenceIT[1:10,] 

#Selecting all dataset convergenceIT but for column 3
convergenceIT[,-3] 

#Selecting according to conditions
#selecting regions belonging to S 
subset <- convergenceIT[convergenceIT$Geo=="S",] 
head(subset)

#selecting regions not belonging to S 
subset <- convergenceIT[convergenceIT$Geo!="S",] 
head(subset)

#selecting regions belonging to NO and having gprb > 0
subset <- convergenceIT[convergenceIT$Geo=="NO" & convergenceIT$gprb > 0,] 
head(subset)

#selecting regions belonging to NO or NE
subset <- convergenceIT[convergenceIT$Geo=="NO" | convergenceIT$Geo=="NE",] 
head(subset)

#selecting regions belonging to NO or NE (alternative way)
subset <- convergenceIT[convergenceIT$Geo %in% c("NO", "NE"),] 
head(subset)

#Merging two different datasets (at least one common variable among the two datasets is needed)
emplProv <- read.csv("Employment_provinces.csv")
head(emplProv)
codRegion <- read.csv("Codes_regions.csv")
head(codRegion)
NewemplProv <- merge(emplProv, codRegion, by="COD_PRO")
head(NewemplProv)

#Aggregating data 
EmplReg <- aggregate(Employm2012 ~ COD_REG, data=NewemplProv, sum)
head(EmplReg)
###############################################
###############################################

###############################################
### Writing data and saving data

#Sometimes it can be of interest to save the data in text files such as CSV files
write.csv(EmplReg, file="EmplReg.csv", row.names=F)

#Let's check
EmplReg2 <- read.csv("EmplReg.csv", header=T) 
all.equal(EmplReg,EmplReg2)

#We can also save R-objects in RData files.
EmplReg3 <- EmplReg
save(EmplReg3, file="EmplReg.RData")

#And then load R-objects in RData files. 
load("EmplReg.RData")
all.equal(EmplReg,EmplReg3)

#If we want to save all the objects created in a work session
save.image("AllObjects.RData")

#To load an RData file
load("AllObjects.RData")

#and we can see its content, that is its objects, by typing
ls()

#We can remove objects within using the command "rm()"
rm(subset)
ls() #see?

rm(convergenceIT2,convergenceIT3)
ls() #see?
###############################################
###############################################

