
##############################################
### General introduction to R, second part ### 
##############################################

###############################################
### Managing variables

setwd(".../Introduction_to_R")
setwd("C:\\Users\\diego.giuliani\\Desktop\\assegno_2011\\corso_Reaction_2017")
convergenceIT <- read.table("convergenceIT.txt", header=T) 

#"Geo"      Macroregion
#"gprb"  Log growth rate (1980-2003) of production per capita
#"lninv1b"	PHYSICAL CAPITAL INVESTMENTS (log scale)
#"pr80b"	production per capita 1980
#"pr103b"	production per capita 2003
#"lndens_emp"	EMPLOYMENT DENSITY (log scale)
#"lndens_pop"	Population DENSITY (log scale)
#"lnagrib"	AGRICULTURE EMPLOYMENT SHARE (log scale)

##############
### Changing names of variables

#changing the name of the third variable of dataset "convergenceIT"
names(convergenceIT)[3] <- "Macroregion"

#changing the name of variables 4 and 5 of dataset "convergenceIT"
names(convergenceIT)[c(4,5)] <- c("logGrowthRate", "Investments")

#changing the name of variables from 8 to 10 of dataset "convergenceIT"
names(convergenceIT)[8:10] <- c("EmploymDens","PopDensity","AgrEmpl") 
##############
##############

##############
### Deleting, creating and transforming variables

#Deleting Variable "AgrEmpl"
convergenceIT$AgrEmpl <- NULL

#Adding the variable "Id" (a progressive number)
convergenceIT$Id <- 1:21

#Adding the variable "Area" (indicating if the region is in the North or Centre-South)
table(convergenceIT$Macroregion)
convergenceIT$Area[convergenceIT$Macroregion=="NE" | convergenceIT$Macroregion=="NO"] <- "North"   
convergenceIT$Area[convergenceIT$Macroregion=="C" | convergenceIT$Macroregion=="S"] <- "Centre-South"  
table(convergenceIT$Area,convergenceIT$Macroregion) #Let's check

#Changing the scale of "logGrowthRate"
convergenceIT$GrowthRate <- exp(convergenceIT$logGrowthRate)

#Creating the ratio between "EmploymDens" and "PopDensity" 
convergenceIT$ratioEmplPop <- convergenceIT$EmploymDens/convergenceIT$PopDensity

#see
help(Arithmetic)
###############################################
###############################################

###############################################
### Basic R-objects: vectors, lists and data frames

##############
### Vectors 

#We have already introduced data frames. Now let's consider the vectors
#The simplest R-object is a vector, a one-dimensional collection of data points of a
#similar kind (such as numbers or text). For instance, in the following code
#we create a vector of 4 numbers and name it "x"
x <- c(3, 6, 9, 12)
x

#Vectors can be of different class. The main, and most common, are:
#numeric: any number (either integer or double).
#character: any string or single character (e.g. "A", "pil")
#factor: any variable which can assume limited and pre-defined categories, like gender or marital status
#logical: typically, TRUE and FALSE
#For example:
xNum <- c(1, 3.14159, 5, 7)
xNum2 <- 1:4
xLog <- c(TRUE, FALSE, TRUE, TRUE)
xChar <- c("abc", "def", "ghi", "lmo")
xFact <- factor(c("abc", "def", "ghi", "lmo"))
xMix <- c(1, TRUE, 3, "Hi there!")

#Indexing denotes particular elements of a data structure. 
#Vectors are indexed with square brackets, [ and ].
# For instance,
xNum[2]

#When you create a vector, R automatically assigns a class to all elements
#in the vector. Some common class are logical (TRUE/FALSE), integer (0, 1,
#When classes are mixed in a vector, it holds values in the most general format.
#The vector xMix was coerced to a character class because only a character class 
#can preserve the basic values of types as diverse as TRUE and Hi there!:
xMix 

#When operating on these, R tries to figure out what to do in a sensible way, 
#but sometimes needs help. For example,
xNum[1]
xMix[1]
xNum[1] + 1
xMix[1] + 1

#We can explicitly force a vector to be numeric by coercion with the as.numeric() function:
as.numeric(xMix[1])+1

#See also:
?as.numeric
?as.character
?as.factor

#The str() (structure) function is a good way to see detailed information about an object:
str(xNum)
str(xChar)
str(xMix)

#Vectors may be appended to one another with c()
x2 <- c(x, x)

#An overall view of an object can be obtained with the summary() function, 
#whose results depend on the object type. 
#For numeric vectors summary() gives range and central tendency statistics, 
#whereas for vectors of characters it reports the length of the vector and the type of the elements:
summary(xNum)
summary(xChar)

#length() provides the number of elements 
length(xNum)
length(xChar)

#Indexing denotes particular elements of a data structure. 
#Vectors are indexed with square brackets, [ and ].
# For instance,
xNum[2]
xNum[2:4]

#For complex sequences, use seq() (sequence) and rep() (replicate).
seq(from=-5, to=28, by=4)
rep(c(1,2,3), each=3)
rep(seq(from=-3, to=13, by=4), c(1, 2, 3, 2, 1))

#Exclude items by using negative indices:
xSeq <- 1:10
xSeq
xSeq[-5:-7]

#The result of an R-vector operation is itself a vector:
xNum[2:4]
xSub <- xNum[2:4]
xSub #Instead of just output, you get an object you can reuse, query, manipulate,
     #update, save, or share.

#Indexing also works with a vector of logical variables (TRUE/FALSE) that indicate
#which elements you want to select:
xNum
xNum[c(FALSE, TRUE, TRUE, TRUE)]

#This allows to use logical expressions, which evaluate as a vector of logical
#values, to select subsets of data based on specific criteria.
xNum > 3
xNum[xNum > 3]

##############
### Missing and peculiar values

#In statistics, missing values are important, and as a statistics environment, 
#R understands them and includes a special constant for a missing value: NA.
#For instance
vect <- c(10, NA, NA)

#Any math performed on a value of NA becomes NA:
mean(vect)
max(vect)

#You may want to tell R to ignore NA data rather than calculating on it. 
#Many commands include an argument that instructs them to ignore
#missing values: na.rm=TRUE:
mean(vect, na.rm=TRUE)
max(vect, na.rm=TRUE)

#A second approach is to remove NA values explicitly before calculating on them
#or assigning them elsewhere. This may be done most easily with the command
#na.omit():
mean(na.omit(vect))

#Missing values can be identified with is.na()
is.na(vect)

#Suppose you want assign zero to missing values
vect[is.na(vect)] <- 0
vect

#R also handles infinity and undefined numbers, with constants Inf and 
#NaN (not a number). For example, if we take the natural logarithm 
#of positive and negative numbers:
log(c(-1,0,1))

##############
### Lists

#Lists are collections of objects of any class and dimension
#Vectors xNum and xChar[-1] are of different class and dimension
str(xNum) 
str(xChar[-1])

#We can combine these two vectors into a list using list()
xList <- list(xNum, xChar[-1])
xList

#Lists are indexed with double brackets ([[ and ]]) instead of the single brackets
#that vectors use, and thus xList comprises two objects that are indexed with
#[[1]] and [[2]].We might index the objects and find summary information one
#at a time, such as:
summary(xList[[1]])

#We can run such a command on all members of the list at
#once. We can do that with the lapply(OBJECT, FUNCTION) command.
#We use lapply() to produce a summary() for each member of the list:
lapply(xList, summary)

#Using lapply() to iterate in this way saves a lot of work, especially with lists
#that may comprise hundreds of objects. It demonstrates that lists have
#two advantages: they keep data in one place regardless of constituent types, and
#they make it possible to apply operations automatically to diverse parts of that data.

#Each element in a list may be assigned a name, which you can access with the
#names() function.
names(xList) <- c("itemnum", "itemchar")
names(xList)
xList

#A list may be indexed using its names rather than a numeric index:
xList[[1]] # method 1: numeric
xList$itemnum # method 2: $name reference
xList[["itemnum"]] # method 3: quoted name

#List names are character strings and may include spaces and various special characters.
#Putting the name in quotes is useful when names include spaces.
###############################################
###############################################




