
#############################################
### General introduction to R, third part ### 
#############################################

setwd(".../Introduction_to_R")

###############################################
### Matrix computations

##########
### Creating matrices

#A matrix can be created in R using the function matrix():
#matrix(data, nrow, ncol, byrow)
?matrix

#to create a 23 matrix A filled by columns: 
A <- matrix(c(3,-5,6,5,0,1),nrow=2,ncol=3)
A

#to create a 23 matrix A filled by rows:
A <- matrix(c(3,-5,6,5,0,1),nrow=2,ncol=3,byrow=T)
A

#R considers column (or row) vectors as matrices with only one column (or row). 
#For example, to create the column vector a and the row vector b, we may type:
a <- matrix(c(5,7,1),nrow=3,ncol=1)
b <- matrix(c(5,4,2),nrow=1,ncol=3)
a
b
##########
##########

##########
### Retrieving the dimension of a matrix

#We can apply function dim() to a matrix in order to get, respectively, its number of rows and columns. 
#For example, to get the dimension of matrices A, b and c previously created, we type:   
A
dim(A)
a
dim(a)
b
dim(b)

#Function length() can be specifically used to identify the dimension (number of elements) of a vector, e.g.
length(a)
length(b)
##########
##########

##########
### Accessing the elements of a matrix

#To select a generic element located at the row i and column j of a matrix A, 
#we simply need to type A[i,j]; 
#for example to select the element with position 1,3 (first row, third column) of the matrix A: 
A[1,3] 

#to select the first row of the matrix A:
A[1,] 

#to select the third column of the matrix A:
A[,3] 

#to select the second and third columns of the matrix A:
A[,c(2,3)] 

#To select a generic element located at the ith position of a vector a, we simply need to type a[i]; 
#for example to select the first element of vector a:
a[1] 

#to select the first and third elements of a vector a:
a[c(1,3)] 

#to select the diagonal of a matrix A we can type 
diag(A)

#We can also use function diag() to create a diagonal matrix starting from a vector 
#which elements we want to compose the diagonal; 
#for example, to get the 44 identity matrix I we may type
ones <- c(1,1,1,1)
I <- diag(ones) 
##########
##########

##########
### Matrix operations

#To compute the sum of two matrices you can use the operator +. 
#For example, to compute the matrix C as a sum of matrices A and B, 
#both generated by a Uniform distribution, we may type
A <- matrix(runif(25), nrow=5, ncol=5)
B <- matrix(runif(25), nrow=5, ncol=5)
A 
B
C <- A+B
C

#To compute the difference of two matrices you can use the operator -. For example,
C <- A-B
C

#To compute the product between a scalar and a matrix you can use the operator *. 
#For example, to compute the product of the scalar a=5 and matrix A, type
a <- 5
C <- a*A
C  

#To compute the matrix product, on the other hand, you can use the operator %*%. For example,
A <- matrix(1:6, nrow=3, ncol=2)
B <- matrix(1:6, nrow=2, ncol=3)
A
B
C <- A%*%B
C

#Operator %*% works also for the product of vectors. Indeed,
a <- 1:6 
b <- matrix(1:6, nrow=6, ncol=1)
a
b
c <- a%*%b 
c

##########
##########

##########
### Inverse of a matrix

#To compute the inverse of a matrix you can use the function solve(). 
#For example, to compute the inverse of the square matrix A, type
A <- matrix(c(1,2,4,4,4,5,6,1,1), nrow=3, ncol=3)
A
Ainv <- solve(A)
Ainv

#Indeed, we can verify that
A%*%Ainv #is an identity matrix.
##########
##########

##########
### Transpose of a matrix

#The R function t() creates the transpose of a matrix (or a vector). 
#For example, we can determine the transpose of the matrix A by typing
A <- matrix(1:6, nrow=2, ncol=3)
A
t(A)

#or we can get the transpose of the vector a with 
a <- matrix(1:6, nrow=6, ncol=1)
a
t(a)
##########
##########

##########
### Advanced matrix operations

#A comprehensive set of R functions that allow to run more advanced matrix operations, 
#such as the Cholesky decomposition, the determinant computation 
#or solving a system of equations, can be found in the package Matrix. 
#see the help page to see the list of functions and a brief description for each of them.
help(package=Matrix)
##########
##########

###############################################
###############################################

###############################################
### Loops

#It frequently happens, especially when we need to run simulations that require many commands, 
#that the flow of operations cannot be sequential 
#(a command after another, from the first row of syntax to the last one) but has to be controlled. 
#In the R environment (as in other programming languages) there are controlling statements 
#that allow to modify the sequence of commands. 
#In particular, we can use conditional statements (when the execution of the sequence of commands depends 
#on a previous result) or loop statements (that allow to repeat the execution of a sequence of commands 
#for a varying number of times).    

##########
### The if statement

#The "if ... else" statement runs alternative flows of execution which depend 
#on the evaluation of a logical condition. The proper syntax is 
#
# if (condition)
# { expression(s) } else
# { alternative expression(s) } 
#
#If the condition is true the expression(s) will be executed, 
#otherwise the alternative expression(s) will be executed. The else statement can be omitted.   

#Run the following examples with different values of x,
x <- 34
if (x>=0)
  {print("x is positive")} else 
  {print("x is negative")}

if (x>=0) sqrt(x) #It is not necessary to define the alternative expression(s). 
##########
##########

##########
### The for loop

#The "for" statement allows to run a sequence of commands for a fixed number of times. The proper syntax is 
#for(var in seq) { operations }
#
#var is an indexing variable and seq can be a vector or a list. The elements in seq are assigned 
#one by one to the variable var and the operations are evaluated cyclically until all the elements 
#in seq have been processed.  
#Run the following example,

x <- c(4, -3.8, 97, 23, -8, -90, 32)
y <- rep(0,7)
for(i in 1:7) {
  if (x[i]>=0) y[i] <- sqrt(x[i])
}
y
##########
##########

##########
### The while loop

#The while statement allows to run a sequence of commands only when a logical condition is verified. 
#The proper syntax is 
#
#while(condition) { operations }
#
#If the condition is true the operations will be executed. The operations will continue to be executed cyclically 
#if the condition remains true. When the condition becomes false the loop stops.      
#Run the following example that computes the multiple of number x which is closest to 1000. 
#Try with different values of x. 

i <- 1
multx <- 1
x <- 7
while (multx <= 1000) {
  multx <- x*i 
  i <- i+1
}
multx

#An analogous, but slightly different, kind of conditional loop statement is the repeat statement. 
#Check out it with 
help("repeat")
##########
##########

###############################################
###############################################

###############################################
### Functions

#Considering also its many external packages, R has an enormous number of functions to perform 
#almost any kind of empirical methods and techniques that you can find in the statistical literature. 
#However, it can be sometimes useful to build your own function which is not already available in R.
#In the R environment a function can be built by using the command function(). 
#To build the function myfunct the proper syntax is
#
#myfunct <- function( input element(s) )
#{
#  operations
#  output element
#}
#
#The output element can be a single object or a list of object.
#As an example, we can build a function that returns a set of descriptive statistics for a set of observations:
DesStat <- function(x)
{
  a <- mean(x)
  b <- sd(x)
  c <- median(x)
  d <- quantile(x, probs=0.25)
  e <- quantile(x, probs=0.75)
  f <- min(x)
  g <- max(x)
  out <- c(a,b,c,d,e,f,g)
  out
} 

#You can save the function as a script file DesStat.R. 
#Then you can recall it anytime you need to use it with source("DesStat.R").
#To apply function DesStat to a simulated sample of 100 heights normally distributed 
#with mean 170 cm and standard deviation 15 cm, type: 
x <- rnorm(100, mean=170, sd=15)
source("DesStat.R")
measures <- DesStat(x) 
measures

#In case you want to visualize only the median, the first and third quartiles, type
measures[c(3,4,5)] 
 
##########
##########

###############################################
###############################################



