
#########################################
### Univariate Descriptive Statistics ###
#########################################

############
### Tabular and graphical summaries for qualitative variables
setwd(".../Introduction_to_R")
convergenceIT <- read.table("convergenceIT.txt", header=T) 

#"Geo"      Macroregion
#"gprb"  Log growth rate (1980-2003) of production per capita
#"lninv1b"	PHYSICAL CAPITAL INVESTMENTS (log scale)
#"pr80b"	production per capita 1980
#"pr103b"	production per capita 2003
#"lndens_emp"	EMPLOYMENT DENSITY (log scale)
#"lndens_pop"	Population DENSITY (log scale)
#"lnagrib"	AGRICULTURE EMPLOYMENT SHARE (log scale)

### Frequency distribution tables
absFreq <- table(convergenceIT$Geo) #Absolute frequencies
absFreq
prop.table(absFreq) #Relative frequencies
round(prop.table(absFreq), digits=2) #we can round them
prop.table(absFreq)*100 #Percentage frequencies

### Bar plot
barplot(absFreq)
barplot(prop.table(absFreq))
barplot(absFreq, col = "red",
        xlab="Macroregion", ylab="Frequency") #you can control a large variety of options, see help(barplot)

### Pie chart
pie(prop.table(absFreq)) #you can control a large variety of options, see help(barplot)
############
############

############
### Tabular and graphical summaries for quantitative variables

### Histogram 
hist(convergenceIT$lndens_emp)
hist(convergenceIT$lndens_emp, main="Histogram of PHYSICAL CAPITAL INVESTMENTS (log scale)", xlab="")

### Stem and leaf chart
stem(convergenceIT$lndens_emp)
############
############

############
### Numerical summaries for quantitative variables

### Central tendencies measures 
mean(convergenceIT$lndens_emp)
median(convergenceIT$lndens_emp)
quantile(convergenceIT$lndens_emp)
quantile(convergenceIT$lndens_emp, probs=0.9)
quantile(convergenceIT$lndens_emp, probs=c(0.1,0.9))

### A fast command to get some summary measures
summary(convergenceIT$lndens_emp)
summary(convergenceIT)

### Boxplot
boxplot(convergenceIT$lndens_emp, horizontal=T)

### Variability measures 
max(convergenceIT$lndens_emp)-min(convergenceIT$lndens_emp) #Range
quantile(convergenceIT$lndens_emp, prob=0.75)-quantile(convergenceIT$lndens_emp, prob=0.25) #IQR
var(convergenceIT$lndens_emp)
sd(convergenceIT$lndens_emp)
############
############

##################################################
### Relationships between continuous variables ###
##################################################

### Scatterplot
plot(convergenceIT$gprb, log(convergenceIT$pr80b)) 
plot(convergenceIT$gprb, log(convergenceIT$pr80b), 
 col="blue",
 xlim=c(-0.010, 0.005), ylim=c(-0.4, 0.05),
 main="Regional economic convergence 1980-2003",
 xlab="Log growth rate 1980_2003", ylab="Log GDP 1980")
 abline(h=mean(log(convergenceIT$pr80b)), col="dark blue", lty="dotted")
 abline(v=mean(convergenceIT$gprb), col="dark blue", lty="dotted") #More fancy!

### Color-coding points on a scatterplot
?colors
#Different colors for different macroregions
table(convergenceIT$Geo)
cols <- c("black", "red", "green3", "yellow")
plot(convergenceIT$gprb, log(convergenceIT$pr80b),
  col=cols[convergenceIT$Geo]) 

### Scatterplot matrix
pairs(convergenceIT[,4:10])

cov(convergenceIT$gprb, log(convergenceIT$pr80b)) #covariance
cor(convergenceIT$gprb, log(convergenceIT$pr80b)) #correlation
cor.test(convergenceIT$gprb, log(convergenceIT$pr80b)) #correlation test

### Correlation matrix
cor(convergenceIT[,4:10])

#####################################
### Finding descriptives by group ###
#####################################

### A useful function that allows to compute summary statistics for groups of data is by()
#by(data, INDICES, FUN)
by(convergenceIT$gprb, convergenceIT$Geo, mean)

### Visualization by group
library(lattice)
histogram(~gprb | Geo, data=convergenceIT)
histogram(~gprb | Geo, data=convergenceIT, type="count", layout=c(4,1), 
                       col=c("burlywood", "darkolivegreen"))

#Let's create the variable "area"
convergenceIT$area[convergenceIT$Geo=="NE" | convergenceIT$Geo=="NO"] <- "North"
convergenceIT$area[convergenceIT$Geo=="C" | convergenceIT$Geo=="S"] <- "Centre-South"
table(convergenceIT$area)
histogram(~gprb | Geo + area, data=convergenceIT)

#Multiple Boxplot
boxplot(gprb ~ Geo, data=convergenceIT)
bwplot(gprb ~ Geo | area, data=convergenceIT)

### Contingency tables
table(convergenceIT$area, convergenceIT$Geo) #Joint frequency distribution
prop.table(table(convergenceIT$area, convergenceIT$Geo), margin=1) #Conditional distribution

### Chi-square test
chisq.test(table(convergenceIT$area, convergenceIT$Geo))

### t.test
by(convergenceIT$gprb, convergenceIT$area, mean)
t.test(gprb ~ area, data=convergenceIT)

### anova
res <- aov(gprb ~ Geo, data=convergenceIT)
anova(res)






















